function plot2(data) {
  // Dictionnaire pour passer du code TRNNETO (ex: "03") au salaire minimal
  const bracketMin = {
    "00": 0,
    "01": 200,
    "02": 500,
    "03": 1000,
    "04": 1500,
    "05": 2000,
    "06": 3000,
    "07": 4000,
    "08": 6000,
    "09": 8000,
    "10": 10000,
    "11": 12000,
    "12": 14000,
    "13": 16000,
    "14": 18000,
    "15": 20000,
    "16": 22000,
    "17": 24000,
    "18": 26000,
    "19": 28000,
    "20": 30000,
    "21": 35000,
    "22": 40000,
    "23": 50000
  };

  // Taille d’une tranche d’heures (par exemple 100 heures)
  const binSize = 100;

  // Objet pour cumuler les salaires par tranche d’heures
  let grouped = {};

  data.forEach(row => {
    const nbHeures = parseFloat(row["NBHEUR_TOT"]);
    // Code TRNNETO (ex: "03"), on le nettoie d’éventuels espaces
    const codeTrn = row["TRNNETO"] ? row["TRNNETO"].trim() : ""; 
    const salaireMin = bracketMin[codeTrn];

    // On s’assure que les valeurs sont valides
    if (isNaN(nbHeures) || salaireMin === undefined) {
      return;
    }

    // Calcul de l’indice de tranche (binIndex)
    const binIndex = Math.floor(nbHeures / binSize);
    
    // Initialisation si la tranche n’existe pas encore
    if (!grouped[binIndex]) {
      grouped[binIndex] = { total: 0, count: 0 };
    }
    // On cumule le salaire minimal dans la tranche
    grouped[binIndex].total += salaireMin;
    grouped[binIndex].count++;
  });

  // Récupère toutes les tranches créées et les trie
  let binKeys = Object.keys(grouped).map(Number);
  binKeys.sort((a, b) => a - b);

  // Prépare les données pour le graphique
  let xValues = [];  // étiquettes de l’axe X
  let yValues = [];  // valeurs (salaire moyen)
  
  binKeys.forEach(binIndex => {
    // Exemple d’étiquette : "0-99h", "100-199h", ...
    let minHeure = binIndex * binSize;
    let maxHeure = (binIndex + 1) * binSize - 1;
    let label = `${minHeure}-${maxHeure}h`;
    
    let avgSalary = grouped[binIndex].total / grouped[binIndex].count;
    
    xValues.push(label);
    yValues.push(avgSalary);
  });

  // Création de la trace Plotly pour un bar chart vertical
  const trace = {
    x: xValues,
    y: yValues,
    type: 'bar'
  };

  // Configuration du layout : on augmente les marges pour voir les titres
  const layout = {
    title: 'Salaire net moyen par tranches d’heures',
    margin: { l: 80, r: 20, t: 60, b: 120 },
    xaxis: {
      title: { 
        text: 'Tranches d’heures (NBHEUR_TOT)', 
        font: { size: 16 } 
      },
      automargin: true
    },
    yaxis: {
      title: { 
        text: 'Salaire net moyen (euros)', 
        font: { size: 16 } 
      },
      automargin: true
    }    
  };

  // On dessine le graphique dans la div #plot2
  Plotly.newPlot('plot2', [trace], layout);
}
