function plot2_gender(data) {
    // Dictionnaire pour convertir le code TRNNETO en salaire minimal
    const bracketMin = {
      "00": 0,   "01": 200,  "02": 500,  "03": 1000,
      "04": 1500, "05": 2000, "06": 3000, "07": 4000,
      "08": 6000, "09": 8000, "10": 10000,"11": 12000,
      "12": 14000,"13": 16000,"14": 18000,"15": 20000,
      "16": 22000,"17": 24000,"18": 26000,"19": 28000,
      "20": 30000,"21": 35000,"22": 40000,"23": 50000
    };
  
    // Taille d’une tranche (bin)
    const binSize = 100;
    // On va regrouper les données dans un objet : pour chaque tranche,
    // stocker deux sous-groupes : male et female.
    let grouped = {};
  
    data.forEach(row => {
      const nbHeures = parseFloat(row["NBHEUR_TOT"]);
      const codeTrn = row["TRNNETO"] ? row["TRNNETO"].trim() : "";
      const salaryMin = bracketMin[codeTrn];
      const sexe = row["SEXE"] ? row["SEXE"].trim() : "";
      
      if (isNaN(nbHeures) || salaryMin === undefined) return;
      if (sexe !== "1" && sexe !== "2") return; // On ne prend en compte que les valeurs 1 et 2
      
      const binIndex = Math.floor(nbHeures / binSize);
      if (!grouped[binIndex]) {
        grouped[binIndex] = { male: { total: 0, count: 0 }, female: { total: 0, count: 0 } };
      }
      if (sexe === "1") {
        grouped[binIndex].male.total += salaryMin;
        grouped[binIndex].male.count++;
      } else if (sexe === "2") {
        grouped[binIndex].female.total += salaryMin;
        grouped[binIndex].female.count++;
      }
    });
  
    // Extraction des tranches et tri
    let binKeys = Object.keys(grouped).map(Number);
    binKeys.sort((a, b) => a - b);
  
    let xValues = [];
    let maleY = [];
    let femaleY = [];
  
    binKeys.forEach(binIndex => {
      let minHeure = binIndex * binSize;
      let maxHeure = (binIndex + 1) * binSize - 1;
      let label = `${minHeure}-${maxHeure}h`;
      xValues.push(label);
      
      let avgMale = grouped[binIndex].male.count > 0 ? grouped[binIndex].male.total / grouped[binIndex].male.count : 0;
      let avgFemale = grouped[binIndex].female.count > 0 ? grouped[binIndex].female.total / grouped[binIndex].female.count : 0;
      
      maleY.push(avgMale);
      femaleY.push(avgFemale);
    });
  
    // Préparation des deux traces pour hommes et femmes
    const traceMale = {
      x: xValues,
      y: maleY,
      type: 'bar',
      name: 'Homme',
      marker: { color: 'blue' }
    };
  
    const traceFemale = {
      x: xValues,
      y: femaleY,
      type: 'bar',
      name: 'Femme',
      marker: { color: 'pink' }
    };
  
    // Configuration du layout avec titres et marges
    const layout = {
      title: 'Salaire net (min de tranche) moyen par tranches d’heures et par sexe',
      margin: { l: 80, r: 20, t: 60, b: 120 },
      xaxis: {
        title: { text: 'Tranches d’heures (NBHEUR_TOT)', font: { size: 16 } },
        automargin: true
      },
      yaxis: {
        title: { text: 'Salaire net moyen (euros)', font: { size: 16 } },
        automargin: true
      },
      barmode: 'group'
    };
  
    // Affiche le graphique dans la div avec l'id "plot2"
    Plotly.newPlot('plot2', [traceMale, traceFemale], layout);
  }
  
  // Ajout d'un écouteur d'événement sur le bouton "genderButton"
  document.getElementById("genderButton").addEventListener("click", function() {
    if (CSVcontent) {
      var lines = CSVcontent.split("\n");
      var dataParsed = getLinesFromHTML(lines);
      plot2_gender(dataParsed);
    } else {
      alert("Veuillez d'abord charger un fichier CSV.");
    }
  });
  