function plotDept(data) {
    // Dictionnaire pour convertir le code TRNNETO en salaire minimal
    const bracketMin = {
      "00": 0,   "01": 200,  "02": 500,  "03": 1000,
      "04": 1500,"05": 2000, "06": 3000, "07": 4000,
      "08": 6000,"09": 8000, "10": 10000,"11": 12000,
      "12": 14000,"13": 16000,"14": 18000,"15": 20000,
      "16": 22000,"17": 24000,"18": 26000,"19": 28000,
      "20": 30000,"21": 35000,"22": 40000,"23": 50000
    };
  
    // Dictionnaire de correspondance pour les départements
    const deptMapping = {
      "01": "Ain",
      "02": "Aisne",
      "03": "Allier",
      "04": "Alpes-de-Haute-Provence",
      "05": "Hautes-Alpes",
      "06": "Alpes-Maritimes",
      "07": "Ardèche",
      "08": "Ardennes",
      "09": "Ariège",
      "10": "Aube",
      "11": "Aude",
      "12": "Aveyron",
      "13": "Bouches-du-Rhône",
      "14": "Calvados",
      "15": "Cantal",
      "16": "Charente",
      "17": "Charente-Maritime",
      "18": "Cher",
      "19": "Corrèze",
      "2A": "Corse-du-Sud",
      "2B": "Haute-Corse",
      "21": "Côte-d'Or",
      "22": "Côtes-d'Armor",
      "23": "Creuse",
      "24": "Dordogne",
      "25": "Doubs",
      "26": "Drôme",
      "27": "Eure",
      "28": "Eure-et-Loir",
      "29": "Finistère",
      "30": "Gard",
      "31": "Haute-Garonne",
      "32": "Gers",
      "33": "Gironde",
      "34": "Hérault",
      "35": "Ille-et-Vilaine",
      "36": "Indre",
      "37": "Indre-et-Loire",
      "38": "Isère",
      "39": "Jura",
      "40": "Landes",
      "41": "Loir-et-Cher",
      "42": "Loire",
      "43": "Haute-Loire",
      "44": "Loire-Atlantique",
      "45": "Loiret",
      "46": "Lot",
      "47": "Lot-et-Garonne",
      "48": "Lozère",
      "49": "Maine-et-Loire",
      "50": "Manche",
      "51": "Marne",
      "52": "Haute-Marne",
      "53": "Mayenne",
      "54": "Meurthe-et-Moselle",
      "55": "Meuse",
      "56": "Morbihan",
      "57": "Moselle",
      "58": "Nièvre",
      "59": "Nord",
      "60": "Oise",
      "61": "Orne",
      "62": "Pas-de-Calais",
      "63": "Puy-de-Dôme",
      "64": "Pyrénées-Atlantiques",
      "65": "Hautes-Pyrénées",
      "66": "Pyrénées-Orientales",
      "67": "Bas-Rhin",
      "68": "Haut-Rhin",
      "69": "Rhône",
      "70": "Haute-Saône",
      "71": "Saône-et-Loire",
      "72": "Sarthe",
      "73": "Savoie",
      "74": "Haute-Savoie",
      "75": "Paris",
      "76": "Seine-Maritime",
      "77": "Seine-et-Marne",
      "78": "Yvelines",
      "79": "Deux-Sèvres",
      "80": "Somme",
      "81": "Tarn",
      "82": "Tarn-et-Garonne",
      "83": "Var",
      "84": "Vaucluse",
      "85": "Vendée",
      "86": "Vienne",
      "87": "Haute-Vienne",
      "88": "Vosges",
      "89": "Yonne",
      "90": "Territoire de Belfort",
      "91": "Essonne",
      "92": "Hauts-de-Seine",
      "93": "Seine-Saint-Denis",
      "94": "Val-de-Marne",
      "95": "Val-d'Oise",
      "971": "Guadeloupe",
      "972": "Martinique",
      "973": "Guyane",
      "974": "La Réunion",
      "99": "Etranger et TOM"
    };
  
    // Regrouper les données par département
    let grouped = {};
    data.forEach(row => {
      let deptCode = row["DEPT"] ? row["DEPT"].trim() : "";
      if (!deptCode) return;
      
      const codeTrn = row["TRNNETO"] ? row["TRNNETO"].trim() : "";
      const salaryMin = bracketMin[codeTrn];
      if (salaryMin === undefined) return;
  
      if (!grouped[deptCode]) {
        grouped[deptCode] = { total: 0, count: 0 };
      }
      grouped[deptCode].total += salaryMin;
      grouped[deptCode].count++;
    });
  
    // Calcul de la moyenne de salaire pour chaque département
    let deptAvgArray = [];
    for (let dept in grouped) {
      let avg = grouped[dept].total / grouped[dept].count;
      deptAvgArray.push({ dept: dept, avg: avg });
    }
  
    // Trier par moyenne décroissante et prendre le top 10
    deptAvgArray.sort((a, b) => b.avg - a.avg);
    let top10 = deptAvgArray.slice(0, 10);
  
    // Préparer les données pour Plotly
    let xValues = top10.map(item => item.avg);
    let yValues = top10.map(item => deptMapping[item.dept] || item.dept);
  
    // Création de la trace pour un diagramme horizontal
    const trace = {
      x: xValues,
      y: yValues,
      type: 'bar',
      orientation: 'h',
      marker: { color: 'teal' }
    };
  
    // Configuration du layout
    const layout = {
      title: 'Top 10 départements selon la moyenne des salaires',
      margin: { l: 150, r: 20, t: 60, b: 60 },
      xaxis: {
        title: { text: 'Salaire net moyen (euros)', font: { size: 16 } },
        automargin: true
      },
      yaxis: {
        title: { text: 'Département', font: { size: 16 } },
        automargin: true,
        autorange: "reversed"
      }
    };
  
    // Tracer le graphique dans la div #plot2
    Plotly.newPlot('plotDept', [trace], layout);
  }
  