// Fonction qui trace le nuage de points.
// Le paramètre highlight2022 détermine si l'année 2022 doit être en rouge ou non.
function plotScatterSalary(highlight2022) {
    // Données réelles (saisies manuellement)
    const salaryData = [
      { annee: "2014", salaireMoyen: 35500 },
      { annee: "2015", salaireMoyen: 36000 },
      { annee: "2016", salaireMoyen: 36500 },
      { annee: "2017", salaireMoyen: 37500 },
      { annee: "2018", salaireMoyen: 38200 },
      { annee: "2019", salaireMoyen: 39600 },
      { annee: "2020", salaireMoyen: 39900 },
      { annee: "2021", salaireMoyen: 40200 },
      { annee: "2022", salaireMoyen: 41600 },
      { annee: "2023", salaireMoyen: 43300 }
    ];
  
    // Extraction des valeurs pour Plotly
    const years = salaryData.map(item => item.annee);
    const salaries = salaryData.map(item => item.salaireMoyen);
  
    // Couleurs : on colorie l’année 2022 en rouge si highlight2022 = true
    const markerColors = salaryData.map(item => {
      if (item.annee === "2022" && highlight2022) {
        return "red";
      } else {
        return "blue";
      }
    });
  
    // Définition de la trace du scatter plot
    const trace = {
      x: years,
      y: salaries,
      mode: 'markers+lines',
      type: 'scatter',
      marker: {
        size: 8,
        color: markerColors
      }
    };
  
    // Configuration du layout
    const layout = {
      title: 'Salaire annuel brut moyen (2014-2023)',
      xaxis: {
        title: { text: 'Année', font: { size: 16 } }
      },
      yaxis: {
        title: { text: 'Salaire moyen (en €)', font: { size: 16 } }
      },
      margin: { l: 80, r: 20, t: 60, b: 80 }
    };
  
    // Affichage du graphique dans la div 'scatterSalary'
    Plotly.newPlot('scatterSalary', [trace], layout);
  }
  
  //  Au chargement de la page, on trace le nuage de points avec 2022 en bleu
  document.addEventListener('DOMContentLoaded', function() {
    plotScatterSalary(false);  // false = on ne met pas 2022 en rouge
  });
  